..
   Copyright DB InfraGO AG and contributors
   SPDX-License-Identifier: Apache-2.0

Welcome to the JSON2Capella documentation!
==========================================


Overview
========

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black
    :alt: Black

**Date**: |today| **Version**: |Version|

JSON2Capella is a command-line application to import package definitions from JSON files into a Capella model's data package.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   usage
   examples

.. toctree::
   :maxdepth: 3
   :caption: API reference

   code/modules



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
